
Welcome to cx_Freeze's documentation!
=====================================

**cx_Freeze** is a set of scripts and modules for freezing Python scripts into
executables in much the same way that py2exe_ and py2app_ do. Unlike these two
tools, cx_Freeze is cross platform and should work on any platform that Python
itself works on. It supports Python_ 3.5.2 or higher.

If you need support for Python 2.x, cx\_Freeze version 5.1.x should be used
instead.

**cx_Freeze** is distributed under an open-source :ref:`license <license>` (the PSF license).

Contents:

.. toctree::
   :maxdepth: 2

   overview.rst
   distutils.rst
   script.rst
   faq.rst
   releasenotes.rst
   development/index.rst
   license.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _py2exe: https://pypi.org/project/py2exe/
.. _py2app: https://pypi.org/project/py2app/
.. _Python: https://www.python.org/
